cosmpy.protos.cosmos.base.tendermint.v1beta1 package — cosmpy documentation

# cosmpy.protos.cosmos.base.tendermint.v1beta1 package

## Submodules

## cosmpy.protos.cosmos.base.tendermint.v1beta1.query_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.base.tendermint.v1beta1.query_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmos.base.tendermint.v1beta1.query_pb2_grpc.Service

  Bases: `object`

  Service defines the gRPC querier service for tendermint queries.

  static GetBlockByHeight(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static GetLatestBlock(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static GetLatestValidatorSet(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static GetNodeInfo(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static GetSyncing(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static GetValidatorSetByHeight(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmos.base.tendermint.v1beta1.query_pb2_grpc.ServiceServicer

  Bases: `object`

  Service defines the gRPC querier service for tendermint queries.

  GetBlockByHeight(request, context)

    GetBlockByHeight queries block for given height.

  GetLatestBlock(request, context)

    GetLatestBlock returns the latest block.

  GetLatestValidatorSet(request, context)

    GetLatestValidatorSet queries latest validator-set.

  GetNodeInfo(request, context)

    GetNodeInfo queries the current node info.

  GetSyncing(request, context)

    GetSyncing queries node syncing.

  GetValidatorSetByHeight(request, context)

    GetValidatorSetByHeight queries validator-set at a given height.

class cosmpy.protos.cosmos.base.tendermint.v1beta1.query_pb2_grpc.ServiceStub(channel)

  Bases: `object`

  Service defines the gRPC querier service for tendermint queries.

cosmpy.protos.cosmos.base.tendermint.v1beta1.query_pb2_grpc.add_ServiceServicer_to_server(servicer, server)

## Module contents